==> hermes-5.3.0.6.multires.tar.gz: hermes-5.3.0.6.multires/app/serializers/hermes/housing_application_serializer.rb <==
# frozen_string_literal: true

module Hermes
  # HousingApplication serializer
  class HousingApplicationSerializer < Hermes::ApplicationSerializer
    #cache key: proc { "#{object.cache_key}" }, expires_in: 1.day
    attributes %i[
      is_active
      applicated_at
      applicant_id
      housing_request_id
      housing_offer_id
      max_date
      epci
      effort_rate
      profile_score
      status
      status_updated_at
      visit_status
      visit_status_updated_at
      eligible_position
      applicated_position
      effort_rate
      housing_request
      visit_conducted_date
      unique_numbers
      date_event
      offer_external_ref
      main_applicant_first_name
      main_applicant_last_name
      request_als_id
      last_status_update_date
      lessor_event_informations
      rank
      last_xml_validation_report
      last_send_has_error
      housing_offer
      business_cotation
    ]
    
    def offer_external_ref
      object.housing_offer&.external_ref
    end
    
    def main_applicant_first_name
      object.housing_request.main_applicant.first_name
    end
    
    def main_applicant_last_name
      object.housing_request.main_applicant.last_name
    end
    
    def request_als_id
      object.housing_request.als_id
    end
    
    def unique_numbers
      object.housing_request&.nuds&.pluck(:unique_number)
    end
    
    def embedded_applicant?
      instance_options[:embedded_applicant] == true
    end
    
    attribute :applicant, if: :embedded_applicant?
    
    type 'housing_applications'
    
    def applicant_id
      object.applicant_id&.to_s
    end
    
    def applicant
      return unless object.applicant
      
      Hermes::ApplicantSerializer.new(
        object.applicant,
        scope: scope,
        root: false
      )
    end
    
    def housing_request_id
      object.housing_request_id&.to_s
    end
    
    def housing_offer_id
      object.housing_offer_id&.to_s
    end
    
    def housing_request
      return unless instance_options[:join_housing_request]
      
      Hermes::HousingRequestSerializer.new(
        object.housing_request,
        scope: scope,
        root: false
      )
    end

    def housing_offer
      return unless instance_options[:join_housing_offer]
      
      Hermes::HousingOfferSerializer.new(
        object.housing_offer,
        scope: scope,
        root: false
      )
    end
  end
end

==> hermes-5.3.0.9.multires.tar.gz: hermes-5.3.0.9.multires/app/serializers/hermes/housing_application_serializer.rb <==
# frozen_string_literal: true

module Hermes
  # HousingApplication serializer
  class HousingApplicationSerializer < Hermes::ApplicationSerializer
    attributes %i[
      is_active
      applicated_at
      applicant_id
      housing_request_id
      housing_offer_id
      max_date
      epci
      effort_rate
      profile_score
      status
      status_updated_at
      visit_status
      visit_status_updated_at
      eligible_position
      applicated_position
      effort_rate
      housing_request
      visit_conducted_date
      unique_numbers
      date_event
      offer_external_ref
      main_applicant_first_name
      main_applicant_last_name
      request_als_id
      last_status_update_date
      lessor_event_informations
      rank
      last_xml_validation_report
      last_send_has_error
      housing_offer
      business_cotation
    ]

    def added_to_object_cache_key
      object&.housing_request&.updated_at.to_i
    end 
    
    def offer_external_ref
      object.housing_offer&.external_ref
    end
    
    def main_applicant_first_name
      object.housing_request.main_applicant.first_name
    end
    
    def main_applicant_last_name
      object.housing_request.main_applicant.last_name
    end
    
    def request_als_id
      object.housing_request.als_id
    end
    
    def unique_numbers
      object.housing_request&.nuds&.pluck(:unique_number)
    end
    
    def embedded_applicant?
      @instance_options[:embedded_applicant] == true
    end
    
    attribute :applicant, if: :embedded_applicant?
    
    type 'housing_applications'
    
    def applicant_id
      object.applicant_id&.to_s
    end
    
    def applicant
      return unless object.applicant
      
      Hermes::ApplicantSerializer.new(
        object.applicant,
        scope: scope,
        root: false
      )
    end
    
    def housing_request_id
      object.housing_request_id&.to_s
    end
    
    def housing_offer_id
      object.housing_offer_id&.to_s
    end
    
    def housing_request
      return unless @instance_options[:join_housing_request]
      
      Hermes::HousingRequestSerializer.new(
        object.housing_request,
        scope: scope,
        root: false
      )
    end

    def housing_offer
      return unless @instance_options[:join_housing_offer]
      
      Hermes::HousingOfferSerializer.new(
        object.housing_offer,
        scope: scope,
        root: false
      )
    end
  end
end
